Developer Documentation
=======================

This section contains documentation for developers working with MindRoot.

.. todo:: Add developer documentation content here

Plugin Examples
---------------

.. list-table:: Example Plugins
   :header-rows: 1
   :widths: 25 40 35

   * - Name
     - Description
     - Source
   * - Override Home Page example
     - Demonstrates how to override the default home page template.
     - `home.jinja2 <https://github.com/runvnc/mindroot/blob/main/src/mindroot/docs/example_plugins/override_home/src/override_home/override/home.jinja2>`_
   * - Run Task example
     - Shows how to submit a task to an agent, wait for completion, and display the result.
     - `home.jinja2 <https://github.com/runvnc/mindroot/blob/main/src/mindroot/docs/example_plugins/run_task/src/run_task/override/home.jinja2>`_

Note the specific directory structure, and the `{# assume-blank #}` comment at the top.


API Reference
-------------

.. todo:: Add API reference documentation

Plugin Development
------------------

.. todo:: Add plugin development guide

Contributing
------------

.. todo:: Add contribution guidelines

Architecture
------------

.. todo:: Add system architecture overview
